%define debug_package %{nil}

Summary:	Internet traffic decoder and network forensic analysis tool

Packager:	Lawrence R. Rogers (lrr@cert.org)

Vendor:		cert.org
Name:		xplico
Version:	0.6.3
Release:	1%{?dist}

License:	GPL

Group:		Applications/Forensics Tools
Source:		%{name}-%{version}.tar.gz
Patch0:		%{name}-%{version}-patch-001

BuildRoot:	%{buildroot}
BuildRequires:	GeoIP-devel
BuildRequires:	mysql-devel
BuildRequires:	sqlite-devel
BuildRequires:	libpcap-devel
Requires:	GeoIP
Requires:	mysql
Requires:	sqlite
Requires:	libpcap
Requires:	wireshark
Requires:	python
Requires:	httpd
Requires:	php-pdo
Requires:	php
Requires:	recode
Requires:	sox
Requires:	lame
Requires:	videosnarf
Requires:	ghostpdl

%description
The goal of Xplico is extract from an internet traffic capture the
applications data contained.  For example, from a pcap file Xplico
extracts each email (POP, IMAP, and SMTP protocols), all HTTP contents,
each VoIP call (SIP), FTP, TFTP, and so on. Xplico isn’t a network
protocol analyzer. Xplico is an open source Network Forensic Analysis Tool
(NFAT).

%prep
%setup  -q
%patch0 -p1
wget http://geolite.maxmind.com/download/geoip/database/GeoLiteCity.dat.gz
if [ -f GeoLiteCity.dat.gz ]; then gunzip GeoLiteCity.dat.gz; fi

%build
%{__make}

%install
make install DESTDIR=$RPM_BUILD_ROOT
################################################################################
# Add the script to manage the service and add the configuration file for the
# local web server.
################################################################################
%__install -Dp init.d/%{name} %{buildroot}/etc/init.d/%{name}
%__install -Dp httpd/%{name}.conf %{buildroot}/etc/httpd/conf.d/%{name}.conf
################################################################################
# Remove the database from the distribution. This is now handled conditionally
# when the package is installed.
################################################################################
rm -f %{buildroot}/opt/xplico/xplico.db

%clean
%{__rm} -rf %{buildroot}

%post

/sbin/chkconfig --del xplico
/sbin/chkconfig --add xplico
DB=/opt/xplico/xplico.db
cd /opt/xplico/script/db/sqlite
if [ -e $DB ]; then
	echo "Preserving previous Xplico database"
	service xplico status | grep -q running
	XPLICO_SERVER_STATUS=$?
	if [ "$XPLICO_SERVER_STATUS" -eq 0 ]; then
		service xplico stop
	fi
	if echo .tables | sqlite3 $DB | grep -q '\<msn_chats\>'
	then
		echo "Database $DB already has msn_chats table"
	else
		echo -n "Adding msn_chats table to $DB..."
		sqlite3 $DB < msns.sql
		echo "done"
	fi
	if echo .tables | sqlite3 $DB | grep -q '\<paltalk_rooms\>'
	then
		echo "Database $DB already has paltalk_rooms table"
	else
		echo -n "Adding paltalk_rooms table to $DB..."
		sqlite3 $DB < paltalks.sql
		echo "done"
	fi
	echo -n "Turning foreign_keys on in database $DB..."
	echo "PRAGMA foreign_keys = ON;" | sqlite3 $DB
	echo "done"
	echo -n "Value of auto_vacuum in database $DB is "
	echo "PRAGMA auto_vacuum ;" | sqlite3 $DB
	if [ "$XPLICO_SERVER_STATUS" -eq 0 ]; then
		service xplico start
	fi
else
	echo "Creating new Xplico database"
	sh create_xplico_db.sh /
fi
if [ -f /usr/bin/pcl6 ]; then
	cp -p /usr/bin/pcl6 /opt/xplico/bin
fi
if [ -f /usr/bin/videosnarf ]; then
	cp -p /usr/bin/videosnarf /opt/xplico/bin
fi

%preun
if [ $1 = 0 ]; then
	/sbin/service xplico stop > /dev/null 2>&1
	/sbin/chkconfig --del xplico
fi
if [ -f /opt/xplico/bin/pcl6 ]; then
	rm -f /opt/xplico/bin/pcl6
fi
if [ -f /opt/xplico/bin/videosnarf ]; then
	rm -f /opt/xplico/bin/videosnarf
fi

%files
%doc AUTHORS ChangeLog COPYING.CC_BY-NC-SA COPYING.GPLv2.0 DEPENDENCES INSTALL README
%defattr(0644, root, root, 0755)
%attr(755, root, root)	/etc/init.d/xplico
%attr(755, root, root)	/etc/httpd/conf.d/xplico.conf
%dir			/opt/xplico/bin/l7-patterns
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/msn-filetransfer.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/smtp.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/ntp.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/nbns.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/x11.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/ident.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/rlogin.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/http-rtsp.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/worldofwarcraft.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/msnmessenger.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/battlefield1942.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/dazhihui.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/uucp.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/pplive.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/ssh.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/teamfortress2.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/radmin.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/live365.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/citrix.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/battlefield2142.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/smb.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/aim.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/qq.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/directconnect.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/subspace.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/nntp.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/gnucleuslan.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/aimwebcontent.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/dns.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/soulseek.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/gkrellm.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/chikka.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/thecircle.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/poco.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/100bao.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/mute.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/dayofdefeat-source.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/unset.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/vnc.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/hotline.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/ciscovpn.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/shoutcast.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/lpd.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/napster.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/hddtemp.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/tesla.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/imap.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/liveforspeed.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/ventrilo.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/unknown.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/ftp.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/h323.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/yahoo.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/quake1.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/ares.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/applejuice.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/finger.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/dhcp.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/battlefield2.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/zmaap.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/gopher.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/rdp.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/counterstrike-source.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/socks.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/biff.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/irc.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/whois.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/cvs.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/skypetoskype.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/fasttrack.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/armagetron.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/teamspeak.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/netbios.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/ncp.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/cimd.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/sip.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/imesh.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/quake-halflife.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/mohaa.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/halflife2-deathmatch.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/guildwars.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/kugoo.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/tsp.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/snmp.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/tftp.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/doom3.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/replaytv-ivs.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/tor.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/rtp.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/xunlei.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/bittorrent.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/telnet.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/tonghuashun.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/gnutella.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/freenet.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/edonkey.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/openft.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/pcanywhere.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/subversion.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/xboxlive.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/bgp.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/jabber.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/soribada.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/ssdp.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/ssl.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/skypeout.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/goboogy.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/http.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/validcertssl.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/stun.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/ipp.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/pop3.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/rtsp.pat
%attr(644, root, root)	/opt/xplico/bin/l7-patterns/runesofmagic.pat
%attr(755, root, root)	/opt/xplico/bin/msite
%attr(755, root, root)	/opt/xplico/bin/wbm_live.py*
%attr(755, root, root)	/opt/xplico/bin/wbm_yahoo.py*
%dir			/opt/xplico/bin/modules
%attr(755, root, root)	/opt/xplico/bin/modules/dis_pop.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_ftp.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_udp_grb.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_http.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_l2tp.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_webmail.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_ppp.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_irc.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_pjl.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_udp_nocheck.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_tcp_soft.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_smtp.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_sip.so
%attr(755, root, root)	/opt/xplico/bin/modules/disp_none.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_tftp.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_imap.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_msn.so
%attr(755, root, root)	/opt/xplico/bin/modules/disp_lite.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_tcp_soft_nocheck.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_fbwchat.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_ip_nocheck.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_rtcp.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_ipv6.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_ieee80211.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_arp.so
%attr(755, root, root)	/opt/xplico/bin/modules/cap_rltm.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_tcp_nocheck.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_vlan.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_telnet.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_icmp.so
%attr(755, root, root)	/opt/xplico/bin/modules/cap_pcap.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_paltalk.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_paltalk_exp.so
%attr(755, root, root)	/opt/xplico/bin/modules/disp_lite_list.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_httpfd.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_radiotap.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_udp.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_tcp_grb.so
%attr(755, root, root)	/opt/xplico/bin/modules/cap_rltm_pol.so
%attr(755, root, root)	/opt/xplico/bin/modules/disp_cli_list.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_dns.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_ipp.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_tcp.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_mms.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_sdp.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_pol.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_pppoe.so
%attr(755, root, root)	/opt/xplico/bin/modules/cap_pol.so
%attr(755, root, root)	/opt/xplico/bin/modules/disp_cli.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_eth.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_pcapf.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_rtp.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_llc.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_nntp.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_ip.so
%attr(755, root, root)	/opt/xplico/bin/modules/dis_sll.so
%attr(755, root, root)	/opt/xplico/bin/mpaltalk
%attr(755, root, root)	/opt/xplico/bin/trigcap
%attr(755, root, root)	/opt/xplico/bin/mfbc
%attr(755, root, root)	/opt/xplico/bin/xplico
%attr(755, root, root)	/opt/xplico/bin/mwmail
%attr(755, root, root)	/opt/xplico/bin/mfile
%attr(755, root, root)	/opt/xplico/bin/wbm_aol.py*
%attr(755, root, root)	/opt/xplico/bin/dema
%dir			/opt/xplico/xi
%attr(644, root, root)	/opt/xplico/xi/README
%attr(644, root, root)	/opt/xplico/xi/._.htaccess
%dir			/opt/xplico/xi/app
%dir			/opt/xplico/xi/app/plugins
%attr(644, root, root)	/opt/xplico/xi/app/plugins/empty
%dir			/opt/xplico/xi/app/models
%attr(644, root, root)	/opt/xplico/xi/app/models/unknow.php
%attr(644, root, root)	/opt/xplico/xi/app/models/dns_message.php
%attr(644, root, root)	/opt/xplico/xi/app/models/msn_chats.php
%attr(644, root, root)	/opt/xplico/xi/app/models/tftp.php
%attr(644, root, root)	/opt/xplico/xi/app/models/fbchat.php
%attr(644, root, root)	/opt/xplico/xi/app/models/paltalk_exp.php
%attr(644, root, root)	/opt/xplico/xi/app/models/input.php
%attr(644, root, root)	/opt/xplico/xi/app/models/ftp_file.php
%attr(644, root, root)	/opt/xplico/xi/app/models/param.php
%attr(755, root, root)	/opt/xplico/xi/app/models/sol.php
%attr(644, root, root)	/opt/xplico/xi/app/models/irc.php
%attr(644, root, root)	/opt/xplico/xi/app/models/web.php
%attr(644, root, root)	/opt/xplico/xi/app/models/tftp_file.php
%attr(755, root, root)	/opt/xplico/xi/app/models/pol.php
%attr(644, root, root)	/opt/xplico/xi/app/models/group.php
%attr(644, root, root)	/opt/xplico/xi/app/models/sip.php
%attr(644, root, root)	/opt/xplico/xi/app/models/arp.php
%attr(644, root, root)	/opt/xplico/xi/app/models/httpfile.php
%attr(644, root, root)	/opt/xplico/xi/app/models/ftp.php
%attr(755, root, root)	/opt/xplico/xi/app/models/source.php
%attr(644, root, root)	/opt/xplico/xi/app/models/telnet.php
%attr(644, root, root)	/opt/xplico/xi/app/models/mmscontent.php
%dir			/opt/xplico/xi/app/models/datasources
%attr(644, root, root)	/opt/xplico/xi/app/models/datasources/empty
%attr(644, root, root)	/opt/xplico/xi/app/models/fbuchat.php
%attr(644, root, root)	/opt/xplico/xi/app/models/rtp.php
%dir			/opt/xplico/xi/app/models/behaviors
%attr(644, root, root)	/opt/xplico/xi/app/models/behaviors/empty
%attr(644, root, root)	/opt/xplico/xi/app/models/nntp_article.php
%attr(644, root, root)	/opt/xplico/xi/app/models/feed_xml.php
%attr(644, root, root)	/opt/xplico/xi/app/models/pjl.php
%attr(644, root, root)	/opt/xplico/xi/app/models/user.php
%attr(644, root, root)	/opt/xplico/xi/app/models/feed.php
%attr(644, root, root)	/opt/xplico/xi/app/models/paltalk_rooms.php
%attr(644, root, root)	/opt/xplico/xi/app/models/nntp_group.php
%attr(644, root, root)	/opt/xplico/xi/app/models/irc_channel.php
%attr(644, root, root)	/opt/xplico/xi/app/models/mm.php
%attr(644, root, root)	/opt/xplico/xi/app/models/email.php
%attr(644, root, root)	/opt/xplico/xi/app/models/webmail.php
%dir			/opt/xplico/xi/app/webroot
%attr(644, root, root)	/opt/xplico/xi/app/webroot/css.php
%attr(644, root, root)	/opt/xplico/xi/app/webroot/favicon.ico
%dir			/opt/xplico/xi/app/webroot/img
%attr(644, root, root)	/opt/xplico/xi/app/webroot/img/deft_link.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/img/dot.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/img/button-xplico.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/img/cake.power.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/img/over_white.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/img/statistics.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/img/is_enhance.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/img/slider.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/img/cake.icon.gif
%attr(644, root, root)	/opt/xplico/xi/app/webroot/img/w3c_xhtml10.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/img/button-iserm.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/img/disable.gif
%attr(644, root, root)	/opt/xplico/xi/app/webroot/img/update.gif
%attr(644, root, root)	/opt/xplico/xi/app/webroot/img/menu-bits.gif
%attr(644, root, root)	/opt/xplico/xi/app/webroot/img/pcapsize.gif
%attr(644, root, root)	/opt/xplico/xi/app/webroot/img/over_close.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/img/enable.gif
%attr(644, root, root)	/opt/xplico/xi/app/webroot/img/cake.power.gif
%attr(644, root, root)	/opt/xplico/xi/app/webroot/img/tick_64.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/img/delete_64.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/img/version.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/img/loading.gif
%attr(644, root, root)	/opt/xplico/xi/app/webroot/img/deft.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/img/database.gif
%attr(644, root, root)	/opt/xplico/xi/app/webroot/img/geoposition.gif
%attr(644, root, root)	/opt/xplico/xi/app/webroot/img/w3c_css.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/index.php
%dir			/opt/xplico/xi/app/webroot/files
%attr(644, root, root)	/opt/xplico/xi/app/webroot/files/flowplayer.controls-3.2.1.swf
%attr(644, root, root)	/opt/xplico/xi/app/webroot/files/flowplayer-3.2.2.swf
%attr(644, root, root)	/opt/xplico/xi/app/webroot/files/xplico_voip_mix.swf
%attr(644, root, root)	/opt/xplico/xi/app/webroot/files/open-flash-chart.swf
%attr(644, root, root)	/opt/xplico/xi/app/webroot/files/xplico_voip.swf
%dir			/opt/xplico/xi/app/webroot/css
%attr(644, root, root)	/opt/xplico/xi/app/webroot/css/html.css
%attr(644, root, root)	/opt/xplico/xi/app/webroot/css/facebookchat.css
%attr(644, root, root)	/opt/xplico/xi/app/webroot/css/style.css
%attr(644, root, root)	/opt/xplico/xi/app/webroot/css/webimages.css
%attr(644, root, root)	/opt/xplico/xi/app/webroot/css/mail.css
%attr(644, root, root)	/opt/xplico/xi/app/webroot/css/cake.generic.css
%dir			/opt/xplico/xi/app/webroot/css/themes
%dir			/opt/xplico/xi/app/webroot/css/themes/ui-darkness
%attr(644, root, root)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/jquery-ui-custom.css
%dir			/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images
%attr(644, root, root)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/pbar-ani.gif
%attr(644, root, root)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-icons_222222_256x240.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_flat_30_cccccc_40x100.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_highlight-soft_80_eeeeee_1x100.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-icons_a83300_256x240.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-icons_cccccc_256x240.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_flat_50_5c5c5c_40x100.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_inset-soft_30_f58400_1x100.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-icons_ffffff_256x240.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_glass_20_555555_1x400.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_glass_40_ffc73d_1x400.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_glass_40_0078a3_1x400.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-icons_4b8e0b_256x240.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_gloss-wave_25_333333_500x100.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/css/themes/ui-darkness/images/ui-bg_inset-soft_25_000000_1x100.png
%attr(644, root, root)	/opt/xplico/xi/app/webroot/css/flows.css
%attr(644, root, root)	/opt/xplico/xi/app/webroot/.htaccess
%dir			/opt/xplico/xi/app/webroot/js
%attr(644, root, root)	/opt/xplico/xi/app/webroot/js/jquery-ui-custom.min.js
%attr(644, root, root)	/opt/xplico/xi/app/webroot/js/jquery.tools.min.js
%attr(644, root, root)	/opt/xplico/xi/app/webroot/js/flowplayer-3.2.2.min.js
%attr(644, root, root)	/opt/xplico/xi/app/webroot/js/http_get.js
%attr(644, root, root)	/opt/xplico/xi/app/webroot/js/check_ver.js
%attr(644, root, root)	/opt/xplico/xi/app/webroot/js/swfobject.js
%attr(644, root, root)	/opt/xplico/xi/app/webroot/js/vendors.php
%attr(644, root, root)	/opt/xplico/xi/app/webroot/js/jquery.js
%dir			/opt/xplico/xi/app/locale
%dir			/opt/xplico/xi/app/locale/eng
%dir			/opt/xplico/xi/app/locale/eng/LC_MESSAGES
%attr(644, root, root)	/opt/xplico/xi/app/locale/eng/LC_MESSAGES/empty
%dir			/opt/xplico/xi/app/config
%attr(644, root, root)	/opt/xplico/xi/app/config/database.php
%attr(644, root, root)	/opt/xplico/xi/app/config/routes.php
%attr(644, root, root)	/opt/xplico/xi/app/config/database.php.sqlite3
%attr(644, root, root)	/opt/xplico/xi/app/config/acl.ini.php
%attr(644, root, root)	/opt/xplico/xi/app/config/inflections.php
%dir			/opt/xplico/xi/app/config/sql
%attr(644, root, root)	/opt/xplico/xi/app/config/sql/i18n.php
%attr(644, root, root)	/opt/xplico/xi/app/config/sql/sessions.php
%attr(644, root, root)	/opt/xplico/xi/app/config/sql/i18n.sql
%attr(644, root, root)	/opt/xplico/xi/app/config/sql/db_acl.sql
%attr(644, root, root)	/opt/xplico/xi/app/config/sql/db_acl.php
%attr(644, root, root)	/opt/xplico/xi/app/config/sql/sessions.sql
%attr(644, root, root)	/opt/xplico/xi/app/config/core.php
%attr(644, root, root)	/opt/xplico/xi/app/config/bootstrap.php
%dir			/opt/xplico/xi/app/views
%dir			/opt/xplico/xi/app/views/scaffolds
%attr(644, root, root)	/opt/xplico/xi/app/views/scaffolds/empty
%dir			/opt/xplico/xi/app/views/rtps
%attr(644, root, root)	/opt/xplico/xi/app/views/rtps/index.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/rtps/caller_play.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/rtps/view.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/rtps/called_play.ctp
%dir			/opt/xplico/xi/app/views/layouts
%attr(644, root, root)	/opt/xplico/xi/app/views/layouts/voip.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/layouts/cookies.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/layouts/licenses.ctp
%dir			/opt/xplico/xi/app/views/layouts/rss
%attr(644, root, root)	/opt/xplico/xi/app/views/layouts/rss/empty
%attr(644, root, root)	/opt/xplico/xi/app/views/layouts/fbchat.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/layouts/rdf.ctp
%dir			/opt/xplico/xi/app/views/layouts/js
%attr(644, root, root)	/opt/xplico/xi/app/views/layouts/js/empty
%attr(644, root, root)	/opt/xplico/xi/app/views/layouts/default.ctp
%dir			/opt/xplico/xi/app/views/layouts/xml
%attr(644, root, root)	/opt/xplico/xi/app/views/layouts/xml/empty
%dir			/opt/xplico/xi/app/views/fbuchats
%attr(644, root, root)	/opt/xplico/xi/app/views/fbuchats/index.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/fbuchats/view.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/fbuchats/chats.ctp
%dir			/opt/xplico/xi/app/views/nntp_groups
%attr(644, root, root)	/opt/xplico/xi/app/views/nntp_groups/alist.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/nntp_groups/index.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/nntp_groups/view.ctp
%dir			/opt/xplico/xi/app/views/paltalk_exps
%attr(644, root, root)	/opt/xplico/xi/app/views/paltalk_exps/index.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/paltalk_exps/chat.ctp
%dir			/opt/xplico/xi/app/views/pjls
%attr(644, root, root)	/opt/xplico/xi/app/views/pjls/index.ctp
%dir			/opt/xplico/xi/app/views/emails
%attr(644, root, root)	/opt/xplico/xi/app/views/emails/index.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/emails/view.ctp
%dir			/opt/xplico/xi/app/views/paltalk_rooms
%attr(644, root, root)	/opt/xplico/xi/app/views/paltalk_rooms/index.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/paltalk_rooms/room.ctp
%dir			/opt/xplico/xi/app/views/webs
%attr(644, root, root)	/opt/xplico/xi/app/views/webs/index.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/webs/method.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/webs/images.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/webs/hijacking.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/webs/play.ctp
%dir			/opt/xplico/xi/app/views/telnets
%attr(644, root, root)	/opt/xplico/xi/app/views/telnets/index.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/telnets/view.ctp
%dir			/opt/xplico/xi/app/views/sips
%attr(644, root, root)	/opt/xplico/xi/app/views/sips/index.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/sips/caller_play.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/sips/view.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/sips/called_play.ctp
%dir			/opt/xplico/xi/app/views/pols
%attr(644, root, root)	/opt/xplico/xi/app/views/pols/index.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/pols/view.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/pols/add.ctp
%dir			/opt/xplico/xi/app/views/feeds
%attr(644, root, root)	/opt/xplico/xi/app/views/feeds/index.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/feeds/view.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/feeds/xml.ctp
%dir			/opt/xplico/xi/app/views/admins
%attr(644, root, root)	/opt/xplico/xi/app/views/admins/users.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/admins/uadd.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/admins/gadd.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/admins/groups.ctp
%dir			/opt/xplico/xi/app/views/msn_chats
%attr(644, root, root)	/opt/xplico/xi/app/views/msn_chats/index.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/msn_chats/chat.ctp
%dir			/opt/xplico/xi/app/views/pages
%attr(644, root, root)	/opt/xplico/xi/app/views/pages/home.ctp
%dir			/opt/xplico/xi/app/views/errors
%attr(644, root, root)	/opt/xplico/xi/app/views/errors/empty
%dir			/opt/xplico/xi/app/views/dns_messages
%attr(644, root, root)	/opt/xplico/xi/app/views/dns_messages/index.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/dns_messages/graph.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/dns_messages/site_graph.ctp
%dir			/opt/xplico/xi/app/views/ircs
%attr(644, root, root)	/opt/xplico/xi/app/views/ircs/index.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/ircs/view.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/ircs/channel.ctp
%dir			/opt/xplico/xi/app/views/helpers
%attr(644, root, root)	/opt/xplico/xi/app/views/helpers/empty
%dir			/opt/xplico/xi/app/views/sols
%attr(644, root, root)	/opt/xplico/xi/app/views/sols/index.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/sols/view.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/sols/add.ctp
%dir			/opt/xplico/xi/app/views/httpfiles
%attr(644, root, root)	/opt/xplico/xi/app/views/httpfiles/index.ctp
%dir			/opt/xplico/xi/app/views/tftps
%attr(644, root, root)	/opt/xplico/xi/app/views/tftps/index.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/tftps/view.ctp
%dir			/opt/xplico/xi/app/views/arps
%attr(644, root, root)	/opt/xplico/xi/app/views/arps/index.ctp
%dir			/opt/xplico/xi/app/views/configurations
%attr(644, root, root)	/opt/xplico/xi/app/views/configurations/index.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/configurations/dissectors.ctp
%dir			/opt/xplico/xi/app/views/users
%attr(644, root, root)	/opt/xplico/xi/app/views/users/index.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/users/gpl.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/users/cc_by_nc_sa.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/users/login.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/users/licenses.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/users/cpassword.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/users/register.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/users/about.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/users/register_confirm.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/users/help.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/users/resend_reg.ctp
%dir			/opt/xplico/xi/app/views/unknows
%attr(644, root, root)	/opt/xplico/xi/app/views/unknows/index.ctp
%dir			/opt/xplico/xi/app/views/mms
%attr(644, root, root)	/opt/xplico/xi/app/views/mms/index.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/mms/view.ctp
%dir			/opt/xplico/xi/app/views/ftps
%attr(644, root, root)	/opt/xplico/xi/app/views/ftps/index.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/ftps/view.ctp
%dir			/opt/xplico/xi/app/views/webmails
%attr(644, root, root)	/opt/xplico/xi/app/views/webmails/index.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/webmails/view.ctp
%dir			/opt/xplico/xi/app/views/elements
%attr(644, root, root)	/opt/xplico/xi/app/views/elements/empty
%dir			/opt/xplico/xi/app/views/inputs
%attr(644, root, root)	/opt/xplico/xi/app/views/inputs/index.ctp
%attr(644, root, root)	/opt/xplico/xi/app/views/inputs/geomap.ctp
%attr(644, root, root)	/opt/xplico/xi/app/index.php
%dir			/opt/xplico/xi/app/controllers
%attr(644, root, root)	/opt/xplico/xi/app/controllers/configurations_controller.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/telnets_controller.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/msn_chats_controller.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/paltalk_rooms_controller.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/feeds_controller.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/commonlib.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/ircs_controller.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/dns_messages_controller.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/paltalk_exps_controller.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/tftps_controller.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/webmails_controller.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/arps_controller.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/sips_controller.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/admins_controller.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/users_controller.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/rfc822_addresses.php
%dir			/opt/xplico/xi/app/controllers/php-ofc-library
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_y_legend.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_line_style.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_bar_base.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_candle.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_radar_axis_labels.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_y_axis_right.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_x_axis_labels.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_bar_glass.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_arrow.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_hbar.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_title.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_pie.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_y_axis_base.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/JSON.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_area_base.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_radar_spoke_labels.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_radar_axis.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_area_line.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_bar_stack.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_scatter.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_upload_image.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_area_hollow.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_sugar.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/README.txt
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_scatter_line.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_tooltip.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_line_dot.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_line_hollow.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_y_axis_label.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_bar.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/json_format.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_tags.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_bar_sketch.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_line_base.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_bar_3d.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/dot_base.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_bar_filled.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_shape.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/open-flash-chart.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/open-flash-chart-object.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_y_axis.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_line.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_x_axis_label.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_menu.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_x_legend.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_x_axis.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/php-ofc-library/ofc_y_axis_labels.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/pjls_controller.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/ftps_controller.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/inputs_controller.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/rtps_controller.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/emails_controller.php
%dir			/opt/xplico/xi/app/controllers/components
%attr(644, root, root)	/opt/xplico/xi/app/controllers/components/xml2_pcap.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/components/search_path.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/components/xplico.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/pols_controller.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/webs_controller.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/httpfiles_controller.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/unknows_controller.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/nntp_groups_controller.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/mms_controller.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/fbuchats_controller.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/sols_controller.php
%attr(644, root, root)	/opt/xplico/xi/app/controllers/mime_parser.php
%dir			/opt/xplico/xi/app/tests
%dir			/opt/xplico/xi/app/tests/fixtures
%attr(644, root, root)	/opt/xplico/xi/app/tests/fixtures/empty
%dir			/opt/xplico/xi/app/tests/groups
%attr(644, root, root)	/opt/xplico/xi/app/tests/groups/empty
%dir			/opt/xplico/xi/app/tests/cases
%dir			/opt/xplico/xi/app/tests/cases/models
%attr(644, root, root)	/opt/xplico/xi/app/tests/cases/models/empty
%dir			/opt/xplico/xi/app/tests/cases/controllers
%attr(644, root, root)	/opt/xplico/xi/app/tests/cases/controllers/empty
%dir			/opt/xplico/xi/app/tests/cases/helpers
%attr(644, root, root)	/opt/xplico/xi/app/tests/cases/helpers/empty
%dir			/opt/xplico/xi/app/tests/cases/behaviors
%attr(644, root, root)	/opt/xplico/xi/app/tests/cases/behaviors/empty
%dir			/opt/xplico/xi/app/tests/cases/components
%attr(644, root, root)	/opt/xplico/xi/app/tests/cases/components/empty
%dir			/opt/xplico/xi/app/vendors
%dir			/opt/xplico/xi/app/vendors/shells
%dir			/opt/xplico/xi/app/vendors/shells/templates
%attr(644, root, root)	/opt/xplico/xi/app/vendors/shells/templates/empty
%dir			/opt/xplico/xi/app/vendors/shells/tasks
%attr(644, root, root)	/opt/xplico/xi/app/vendors/shells/tasks/empty
%attr(644, root, root)	/opt/xplico/xi/app/.htaccess
%attr(644, root, root)	/opt/xplico/xi/app/LICENSE
%dir			/opt/xplico/xi/app/tmp
%dir			/opt/xplico/xi/app/tmp/cache
%dir			/opt/xplico/xi/app/tmp/cache/models
%dir			/opt/xplico/xi/app/tmp/cache/persistent
%dir			/opt/xplico/xi/app/tmp/cache/views
%dir			/opt/xplico/xi/app/tmp/sessions
%attr(644, root, root)	/opt/xplico/xi/app/tmp/sessions/empty
%dir			/opt/xplico/xi/app/tmp/tests
%attr(644, root, root)	/opt/xplico/xi/app/tmp/tests/empty
%dir			/opt/xplico/xi/app/tmp/logs
%attr(644, root, root)	/opt/xplico/xi/app/tmp/logs/empty
%attr(644, root, root)	/opt/xplico/xi/index.php
%dir			/opt/xplico/xi/cake
%dir			/opt/xplico/xi/cake/config
%attr(644, root, root)	/opt/xplico/xi/cake/config/config.php
%attr(644, root, root)	/opt/xplico/xi/cake/config/paths.php
%dir			/opt/xplico/xi/cake/config/unicode
%dir			/opt/xplico/xi/cake/config/unicode/casefolding
%attr(644, root, root)	/opt/xplico/xi/cake/config/unicode/casefolding/2460_24ff.php
%attr(644, root, root)	/opt/xplico/xi/cake/config/unicode/casefolding/0080_00ff.php
%attr(644, root, root)	/opt/xplico/xi/cake/config/unicode/casefolding/ff00_ffef.php
%attr(644, root, root)	/opt/xplico/xi/cake/config/unicode/casefolding/0250_02af.php
%attr(644, root, root)	/opt/xplico/xi/cake/config/unicode/casefolding/0370_03ff.php
%attr(644, root, root)	/opt/xplico/xi/cake/config/unicode/casefolding/2c60_2c7f.php
%attr(644, root, root)	/opt/xplico/xi/cake/config/unicode/casefolding/2150_218f.php
%attr(644, root, root)	/opt/xplico/xi/cake/config/unicode/casefolding/1e00_1eff.php
%attr(644, root, root)	/opt/xplico/xi/cake/config/unicode/casefolding/2c00_2c5f.php
%attr(644, root, root)	/opt/xplico/xi/cake/config/unicode/casefolding/2c80_2cff.php
%attr(644, root, root)	/opt/xplico/xi/cake/config/unicode/casefolding/2100_214f.php
%attr(644, root, root)	/opt/xplico/xi/cake/config/unicode/casefolding/0500_052f.php
%attr(644, root, root)	/opt/xplico/xi/cake/config/unicode/casefolding/0400_04ff.php
%attr(644, root, root)	/opt/xplico/xi/cake/config/unicode/casefolding/0100_017f.php
%attr(644, root, root)	/opt/xplico/xi/cake/config/unicode/casefolding/0180_024F.php
%attr(644, root, root)	/opt/xplico/xi/cake/config/unicode/casefolding/0530_058f.php
%attr(644, root, root)	/opt/xplico/xi/cake/config/unicode/casefolding/1f00_1fff.php
%attr(644, root, root)	/opt/xplico/xi/cake/dispatcher.php
%attr(644, root, root)	/opt/xplico/xi/cake/LICENSE.txt
%dir			/opt/xplico/xi/cake/libs
%attr(644, root, root)	/opt/xplico/xi/cake/libs/security.php
%dir			/opt/xplico/xi/cake/libs/cache
%attr(644, root, root)	/opt/xplico/xi/cake/libs/cache/xcache.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/cache/apc.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/cache/file.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/cache/memcache.php
%dir			/opt/xplico/xi/cake/libs/controller
%attr(644, root, root)	/opt/xplico/xi/cake/libs/controller/pages_controller.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/controller/controller.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/controller/scaffold.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/controller/app_controller.php
%dir			/opt/xplico/xi/cake/libs/controller/components
%attr(644, root, root)	/opt/xplico/xi/cake/libs/controller/components/security.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/controller/components/session.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/controller/components/cookie.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/controller/components/request_handler.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/controller/components/acl.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/controller/components/auth.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/controller/components/email.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/controller/component.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/string.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/overloadable.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/folder.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/flay.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/session.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/i18n.php
%dir			/opt/xplico/xi/cake/libs/model
%attr(644, root, root)	/opt/xplico/xi/cake/libs/model/connection_manager.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/model/model.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/model/app_model.php
%dir			/opt/xplico/xi/cake/libs/model/datasources
%attr(644, root, root)	/opt/xplico/xi/cake/libs/model/datasources/datasource.php
%dir			/opt/xplico/xi/cake/libs/model/datasources/dbo
%attr(644, root, root)	/opt/xplico/xi/cake/libs/model/datasources/dbo/dbo_postgres.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/model/datasources/dbo/dbo_oracle.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/model/datasources/dbo/dbo_odbc.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/model/datasources/dbo/dbo_sybase.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/model/datasources/dbo/dbo_mssql.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/model/datasources/dbo/dbo_adodb.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/model/datasources/dbo/dbo_mysqli.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/model/datasources/dbo/dbo_sqlite.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/model/datasources/dbo/dbo_db2.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/model/datasources/dbo/dbo_mysql.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/model/datasources/dbo/dbo_firebird.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/model/datasources/dbo/dbo_sqlite3.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/model/datasources/dbo_source.php
%dir			/opt/xplico/xi/cake/libs/model/behaviors
%attr(644, root, root)	/opt/xplico/xi/cake/libs/model/behaviors/containable.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/model/behaviors/acl.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/model/behaviors/translate.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/model/behaviors/tree.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/model/behavior.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/model/db_acl.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/model/schema.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/object.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/error.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/magic_db.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/cache.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/cake_log.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/class_registry.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/configure.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/router.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/sanitize.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/overloadable_php4.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/set.php
%dir			/opt/xplico/xi/cake/libs/view
%dir			/opt/xplico/xi/cake/libs/view/scaffolds
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/scaffolds/index.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/scaffolds/view.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/scaffolds/edit.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/view.php
%dir			/opt/xplico/xi/cake/libs/view/layouts
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/layouts/flash.ctp
%dir			/opt/xplico/xi/cake/libs/view/layouts/rss
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/layouts/rss/default.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/layouts/ajax.ctp
%dir			/opt/xplico/xi/cake/libs/view/layouts/js
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/layouts/js/default.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/layouts/default.ctp
%dir			/opt/xplico/xi/cake/libs/view/layouts/email
%dir			/opt/xplico/xi/cake/libs/view/layouts/email/html
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/layouts/email/html/default.ctp
%dir			/opt/xplico/xi/cake/libs/view/layouts/email/text
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/layouts/email/text/default.ctp
%dir			/opt/xplico/xi/cake/libs/view/layouts/xml
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/layouts/xml/default.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/media.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/helper.php
%dir			/opt/xplico/xi/cake/libs/view/pages
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/pages/home.ctp
%dir			/opt/xplico/xi/cake/libs/view/errors
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/errors/missing_table.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/errors/missing_helper_class.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/errors/missing_controller.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/errors/missing_scaffolddb.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/errors/missing_connection.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/errors/missing_action.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/errors/private_action.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/errors/scaffold_error.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/errors/missing_model.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/errors/missing_component_file.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/errors/missing_component_class.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/errors/missing_layout.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/errors/missing_view.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/errors/missing_helper_file.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/errors/error404.ctp
%dir			/opt/xplico/xi/cake/libs/view/helpers
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/helpers/number.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/helpers/ajax.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/helpers/session.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/helpers/html.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/helpers/js.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/helpers/cache.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/helpers/form.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/helpers/paginator.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/helpers/app_helper.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/helpers/text.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/helpers/time.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/helpers/javascript.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/helpers/xml.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/helpers/rss.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/theme.php
%dir			/opt/xplico/xi/cake/libs/view/elements
%dir			/opt/xplico/xi/cake/libs/view/elements/email
%dir			/opt/xplico/xi/cake/libs/view/elements/email/html
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/elements/email/html/default.ctp
%dir			/opt/xplico/xi/cake/libs/view/elements/email/text
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/elements/email/text/default.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/libs/view/elements/dump.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/libs/overloadable_php5.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/file.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/debugger.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/validation.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/xml.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/http_socket.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/inflector.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/socket.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/l10n.php
%attr(644, root, root)	/opt/xplico/xi/cake/libs/multibyte.php
%attr(644, root, root)	/opt/xplico/xi/cake/VERSION.txt
%attr(644, root, root)	/opt/xplico/xi/cake/basics.php
%dir			/opt/xplico/xi/cake/console
%attr(644, root, root)	/opt/xplico/xi/cake/console/error.php
%attr(644, root, root)	/opt/xplico/xi/cake/console/cake.php
%attr(755, root, root)	/opt/xplico/xi/cake/console/cake
%dir			/opt/xplico/xi/cake/console/libs
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/shell.php
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/i18n.php
%dir			/opt/xplico/xi/cake/console/libs/templates
%dir			/opt/xplico/xi/cake/console/libs/templates/views
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/views/index.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/views/view.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/views/form.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/views/home.ctp
%dir			/opt/xplico/xi/cake/console/libs/templates/skel
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/plugins
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/plugins/empty
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/models
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/models/datasources
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/models/datasources/empty
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/models/behaviors
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/models/behaviors/empty
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/webroot
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/webroot/test.php
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/webroot/css.php
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/webroot/favicon.ico
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/webroot/img
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/webroot/img/cake.icon.gif
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/webroot/img/cake.power.gif
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/webroot/index.php
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/webroot/css
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/webroot/css/cake.generic.css
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/webroot/.htaccess
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/webroot/js
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/webroot/js/vendors.php
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/locale
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/locale/eng
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/locale/eng/LC_MESSAGES
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/locale/eng/LC_MESSAGES/empty
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/app_helper.php
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/config
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/config/routes.php
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/config/acl.ini.php
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/config/inflections.php
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/config/database.php.default
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/config/sql
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/config/sql/i18n.php
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/config/sql/sessions.php
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/config/sql/i18n.sql
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/config/sql/db_acl.sql
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/config/sql/db_acl.php
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/config/sql/sessions.sql
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/config/core.php
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/config/bootstrap.php
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/views
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/views/scaffolds
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/views/scaffolds/empty
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/views/layouts
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/views/layouts/flash.ctp
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/views/layouts/rss
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/views/layouts/rss/default.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/views/layouts/ajax.ctp
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/views/layouts/js
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/views/layouts/js/default.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/views/layouts/default.ctp
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/views/layouts/email
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/views/layouts/email/html
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/views/layouts/email/html/default.ctp
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/views/layouts/email/text
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/views/layouts/email/text/default.ctp
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/views/layouts/xml
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/views/layouts/xml/default.ctp
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/views/pages
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/views/pages/empty
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/views/errors
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/views/errors/empty
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/views/helpers
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/views/helpers/empty
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/views/elements
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/views/elements/empty
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/views/elements/email
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/views/elements/email/html
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/views/elements/email/html/default.ctp
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/views/elements/email/text
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/views/elements/email/text/default.ctp
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/index.php
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/app_model.php
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/controllers
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/controllers/pages_controller.php
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/controllers/components
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/controllers/components/empty
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/app_controller.php
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/tests
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/tests/fixtures
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/tests/fixtures/empty
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/tests/groups
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/tests/groups/empty
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/tests/cases
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/tests/cases/models
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/tests/cases/models/empty
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/tests/cases/controllers
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/tests/cases/controllers/empty
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/tests/cases/helpers
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/tests/cases/helpers/empty
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/tests/cases/behaviors
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/tests/cases/behaviors/empty
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/tests/cases/components
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/tests/cases/components/empty
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/vendors
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/vendors/shells
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/vendors/shells/templates
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/vendors/shells/templates/empty
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/vendors/shells/tasks
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/vendors/shells/tasks/empty
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/.htaccess
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/tmp
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/tmp/cache
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/tmp/cache/models
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/tmp/cache/models/empty
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/tmp/cache/persistent
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/tmp/cache/persistent/empty
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/tmp/cache/views
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/tmp/cache/views/empty
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/tmp/sessions
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/tmp/sessions/empty
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/tmp/tests
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/tmp/tests/empty
%dir			/opt/xplico/xi/cake/console/libs/templates/skel/tmp/logs
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/templates/skel/tmp/logs/empty
%dir			/opt/xplico/xi/cake/console/libs/tasks
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/tasks/test.php
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/tasks/view.php
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/tasks/model.php
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/tasks/extract.php
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/tasks/controller.php
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/tasks/plugin.php
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/tasks/db_config.php
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/tasks/project.php
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/testsuite.php
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/bake.php
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/acl.php
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/api.php
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/schema.php
%attr(644, root, root)	/opt/xplico/xi/cake/console/libs/console.php
%attr(644, root, root)	/opt/xplico/xi/cake/console/cake.bat
%attr(644, root, root)	/opt/xplico/xi/cake/bootstrap.php
%dir			/opt/xplico/xi/vendors
%attr(755, root, root)	/opt/xplico/xi/vendors/._simpletest
%dir			/opt/xplico/xi/vendors/css
%attr(644, root, root)	/opt/xplico/xi/vendors/css/empty
%dir			/opt/xplico/xi/vendors/js
%attr(644, root, root)	/opt/xplico/xi/vendors/js/empty
%dir			/opt/xplico/xi/vendors/shells
%dir			/opt/xplico/xi/vendors/shells/templates
%attr(644, root, root)	/opt/xplico/xi/vendors/shells/templates/empty
%dir			/opt/xplico/xi/vendors/shells/tasks
%attr(644, root, root)	/opt/xplico/xi/vendors/shells/tasks/empty
%attr(644, root, root)	/opt/xplico/xi/.htaccess
%attr(644, root, root)	/opt/xplico/GeoLiteCity.dat
%attr(644, root, root)	/opt/xplico/COPYING.CC_BY-NC-SA
%attr(644, root, root)	/opt/xplico/COPYING.GPLv2.0
%dir			/opt/xplico/script
%dir			/opt/xplico/script/db
%dir			/opt/xplico/script/db/mysql
%dir			/opt/xplico/script/db/sqlite
%attr(644, root, root)	/opt/xplico/script/db/sqlite/httpfiles.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/webmail.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/ftps.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/sources.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/arps.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/pols.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/tftps.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/default.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/fbchats.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/feeds.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/mms.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/inputs.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/feed_xmls.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/msns.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/users.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/rtps.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/groups.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/tftp_files.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/ftp_files.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/telnets.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/nntp_articles.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/pjls.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/webs.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/mmscontents.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/paltalk_exps.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/ircs.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/fbuchats.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/sips.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/nntp_groups.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/dns_messages.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/paltalks.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/params.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/sols.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/unknows.sql
%attr(644, root, root)	/opt/xplico/script/db/sqlite/irc_channels.sql
%attr(755, root, root)	/opt/xplico/script/db/sqlite/create_xplico_db.sh
%attr(644, root, root)	/opt/xplico/script/db/sqlite/emails.sql
%attr(755, root, root)	/opt/xplico/script/mimedump.pyc
%attr(755, root, root)	/opt/xplico/script/xplico.rltm.console
%attr(755, root, root)	/opt/xplico/script/sqlite_demo.sh
%attr(755, root, root)	/opt/xplico/script/xplico
%attr(755, root, root)	/opt/xplico/script/xml2pcap.php
%attr(755, root, root)	/opt/xplico/script/session_mng.pyc
%dir			/opt/xplico/cfg
%attr(644, root, root)	/opt/xplico/cfg/xplico_install_mysql.cfg
%attr(644, root, root)	/opt/xplico/cfg/mpaltalk_install_lite.cfg
%attr(644, root, root)	/opt/xplico/cfg/xplico_cli.cfg
%attr(644, root, root)	/opt/xplico/cfg/xplico_cli_nc.cfg
%attr(644, root, root)	/opt/xplico/cfg/mpaltalk_install_mysql.cfg
%attr(644, root, root)	/opt/xplico/cfg/mfbc_install_lite.cfg
%attr(644, root, root)	/opt/xplico/cfg/mwmail_cli.cfg
%attr(644, root, root)	/opt/xplico/cfg/apache_xi
%attr(644, root, root)	/opt/xplico/cfg/mfile_cli.cfg
%attr(644, root, root)	/opt/xplico/cfg/sol_subdir.cfg
%attr(644, root, root)	/opt/xplico/cfg/mfbc_install_mysql.cfg
%attr(644, root, root)	/opt/xplico/cfg/mfile_install_mysql.cfg
%attr(644, root, root)	/opt/xplico/cfg/xplico_install_lite.cfg
%attr(644, root, root)	/opt/xplico/cfg/mwmail_install_mysql.cfg
%attr(644, root, root)	/opt/xplico/cfg/mfile_install_lite.cfg
%attr(644, root, root)	/opt/xplico/cfg/mpaltalk_cli.cfg
%attr(644, root, root)	/opt/xplico/cfg/mwmail_install_lite.cfg
%attr(644, root, root)	/opt/xplico/LICENSE
%dir			/opt/xplico/log

%changelog
* Mon Jun 6 2011 Lawrence Rogers <lrr@cert.org> 0.6.3-1
* Release 0.6.3-1
	* xplico 32/64bit version
	* new decoding manager (DeMa) version 0.3.1
	* mfile manipulator (HTTP file transfare) bug fixes
	* WebMail scripts improved
	* HTTP dissector improved
	* upgraded the XI javascript libraries

* Tue May 3 2011 Lawrence Rogers <lrr@cert.org>  0.6.2-1
* Revision 1: Upgrade to 0.6.2 doing the following:
	l7-patterns for all flows/protocols not decoded by xplico
	Xplico Interface (XI) improved
	python3 porting of many script
	realtime capture module improved
	facebook chat realtime view
	UTC/localtime bug fixes
	l2tp dissector bug fixes
	cli and lite dispatchers bug fixes
	telnet dissector bug fixes

* Tue Mar 1 2011 Lawrence Rogers <lrr@cert.org>  0.6.1-6
* Revision 6: The /etc/init.d/xplico script no longer specific the start and stop levels.
	      These should be done identical to and after httpd, so that xplico is
		set to start after httpd.

* Fri Dec 10 2010 Lawrence Rogers <lrr@cert.org>  0.6.1-5
* Revision 5: Fixed init.d script so that it waits until httpd starts

* Thu Dec 9 2010 Lawrence Rogers <lrr@cert.org>  0.6.1-4
* Revision 4: Fixed init.d script so that it is started after httpd

* Thu Dec 9 2010 Lawrence Rogers <lrr@cert.org>  0.6.1-3
* Revision 3: Stops and restarts the server, if necessary, before adding any tables and PRAGMA values

* Thu Dec 9 2010 Lawrence Rogers <lrr@cert.org>  0.6.1-2
* Revision 2: Changed the postun script to add the msn_chats and paltalk_rooms tables to an existing database.
		Also the foreign_keys PRAGMA was turned on and the auto_vacuum value displayed.`

* Tue Dec 7 2010 Lawrence Rogers <lrr@cert.org>  0.6.1-1
* Revision 1: Version 0.6.1 from www.xplico.org

* Mon Nov 29 2010 Lawrence Rogers <lrr@cert.org> 0.6.0-10
- Revision 10: Improved (fixed?) /etc/init.d/xplico so that it waits longer for httpd to start.
  Also added httpd as a service start dependency.

* Fri Nov 19 2010 Lawrence Rogers <lrr@cert.org> 0.6.0-9
- Revision 9: 

* Thu Nov 18 2010 Lawrence Rogers <lrr@cert.org> 0.6.0-8
- Revision 8: Correctly removes pcl6 and videosnarf as pre-uninstall scripts so that the
  /opt/xplico hierarchy can be completely removed if possible when xplico is removed.

* Thu Nov 18 2010 Lawrence Rogers <lrr@cert.org> 0.6.0-7
- Revision 7: Removed pcl6 and videosnarf and made those packages prerequisites. The needed
  binaries are then copied into the /opt/xplico hierarchy using the post-install script.
  Also, the correct syntax for creating the dabase is used.

* Thu Nov 18 2010 Lawrence Rogers <lrr@cert.org> 0.6.0-6
- Revision 6: Added pcl6 and videosnarf

* Thu Nov 18 2010 Lawrence Rogers <lrr@cert.org>  0.6.0-5
- Revision 5: Fixed permissions to match those of the Debian package
  Also preserves any existing database by creating the database in the post-install script,
  as needed.

* Wed Nov 18 2010 Lawrence Rogers <lrr@cert.org> 0.6.0-4
- Revision 4: Gave execute permissions to everything in the bin directory
